@@ -26,27 +26,27 @@ Examples:
   print y.derivatives[x]  # Partial derivative: prints "2"
   
   # List of all sources of error:
-  x = uncertainties.Number_with_uncert((0.2, 0.05), "x variable")  # Tag
-  y = uncertainties.Number_with_uncert((10,  0.1),  "y variable")
-  sum_value = x+y
+  u = uncertainties.Number_with_uncert((0.2, 0.05), "u variable")  # Tag
+  v = uncertainties.Number_with_uncert((10,  0.1),  "v variable")
+  sum_value = u+v
   print sum_value  # Prints "10.2+-0.11..."
   for (var, error) in sum_value.error_components().iteritems():
       print "%s: %f" % (var.tag, error)  # Individual error components
 
   # Correlations:
-  x.set_std_dev(0.1)  # Standard deviations can be updated on the fly
-  print y - x**2  # Prints "0.0" (exact result)
+  u.set_std_dev(0.1)  # Standard deviations can be updated on the fly
+  print sum_value - u - v  # Prints "0.0" (exact result)
 
   # Correlation matrices:
-  correlation_matrix = uncertainties.correlations([x, y, x+y])
+  correlation_matrix = uncertainties.correlations([u, v, u+v])
   print correlation_matrix  # 3x3 matrix
 
   # Correlated variables can be constructed from a correlation matrix, if
   # Numpy is available:
-  (x2, y2, sum2) = uncertainties.correlated_values([0.2, 10, 10.2],
+  (u2, v2, sum2) = uncertainties.correlated_values([0.2, 10, 10.2],
                                                    correlation_matrix)
-  print x2  # Value and uncertainty of x: correctly recovered (0.2+-0.05)
-  print uncertainties.correlations([x2, y2, sum2])  # = correlation_matrix
+  print u2  # Value and uncertainty of u: correctly recovered (0.2+-0.05)
+  print uncertainties.correlations([u2, u2, sum2])  # = correlation_matrix
 
 - The main class provided by this module is Number_with_uncert, which
 represents numbers with uncertainties.  Number_with_uncert objects can
